==> colourvalues_0.2.2.tar.gz: colourvalues/inst/include/colourvalues/palettes/ygobb.hpp <==
#ifndef R_COLOURVALUES_YGOBB_H
#define R_COLOURVALUES_YGOBB_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector ygobb_red = {
    1,0.996078431372549,0.988235294117647,0.984313725490196,
    0.980392156862745,0.972549019607843,0.968627450980392,0.964705882352941,
    0.956862745098039,0.952941176470588,0.949019607843137,0.941176470588235,
    0.937254901960784,0.933333333333333,0.925490196078431,0.92156862745098,
    0.917647058823529,0.909803921568627,0.905882352941176,0.901960784313726,
    0.894117647058824,0.890196078431372,0.886274509803922,0.87843137254902,
    0.874509803921569,0.870588235294118,0.862745098039216,0.858823529411765,
    0.854901960784314,0.847058823529412,0.843137254901961,0.83921568627451,
    0.831372549019608,0.827450980392157,0.823529411764706,0.815686274509804,
    0.811764705882353,0.807843137254902,0.8,0.796078431372549,
    0.792156862745098,0.784313725490196,0.780392156862745,0.776470588235294,
    0.768627450980392,0.764705882352941,0.76078431372549,0.752941176470588,
    0.749019607843137,0.745098039215686,0.737254901960784,0.733333333333333,
    0.729411764705882,0.72156862745098,0.717647058823529,0.713725490196078,
    0.705882352941177,0.701960784313725,0.698039215686274,0.690196078431373,
    0.686274509803922,0.682352941176471,0.674509803921569,0.670588235294118,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.662745098039216,0.658823529411765,0.654901960784314,0.647058823529412,
    0.643137254901961,0.63921568627451,0.631372549019608,0.627450980392157,
    0.623529411764706,0.615686274509804,0.611764705882353,0.607843137254902,
    0.6,0.596078431372549,0.592156862745098,0.584313725490196,
    0.580392156862745,0.576470588235294,0.568627450980392,0.564705882352941,
    0.56078431372549,0.552941176470588,0.549019607843137,0.545098039215686,
    0.537254901960784,0.533333333333333,0.529411764705882,0.52156862745098,
    0.517647058823529,0.513725490196078,0.505882352941176,0.501960784313725,
    0.498039215686275,0.490196078431373,0.486274509803922,0.482352941176471,
    0.474509803921569,0.470588235294118,0.466666666666667,0.458823529411765,
    0.454901960784314,0.450980392156863,0.443137254901961,0.43921568627451,
    0.435294117647059,0.427450980392157,0.423529411764706,0.419607843137255,
    0.411764705882353,0.407843137254902,0.403921568627451,0.396078431372549,
    0.392156862745098,0.388235294117647,0.380392156862745,0.376470588235294,
    0.372549019607843,0.364705882352941,0.36078431372549,0.356862745098039,
    0.349019607843137,0.345098039215686,0.341176470588235,0.333333333333333,
    0.329411764705882,0.325490196078431,0.317647058823529,0.313725490196078,
    0.309803921568627,0.301960784313725,0.298039215686275,0.294117647058824,
    0.286274509803922,0.282352941176471,0.27843137254902,0.270588235294118,
    0.266666666666667,0.262745098039216,0.254901960784314,0.250980392156863,
    0.247058823529412,0.23921568627451,0.235294117647059,0.231372549019608,
    0.223529411764706,0.219607843137255,0.215686274509804,0.207843137254902,
    0.203921568627451,0.2,0.192156862745098,0.188235294117647,
    0.184313725490196,0.176470588235294,0.172549019607843,0.168627450980392,
    0.16078431372549,0.156862745098039,0.152941176470588,0.145098039215686,
    0.141176470588235,0.137254901960784,0.129411764705882,0.125490196078431,
    0.12156862745098,0.113725490196078,0.109803921568627,0.105882352941176,
    0.0980392156862745,0.0941176470588235,0.0901960784313725,0.0823529411764706,
    0.0784313725490196,0.0745098039215686,0.0666666666666667,0.0627450980392157,
    0.0588235294117647,0.0509803921568627,0.0470588235294118,0.0431372549019608,
    0.0352941176470588,0.0313725490196078,0.0274509803921569,0.0196078431372549,
    0.0156862745098039,0.0117647058823529,0.00392156862745098,0
  };

  const Rcpp::NumericVector ygobb_green = {
    1,0.996078431372549,0.988235294117647,0.984313725490196,
    0.980392156862745,0.972549019607843,0.968627450980392,0.964705882352941,
    0.956862745098039,0.952941176470588,0.949019607843137,0.941176470588235,
    0.937254901960784,0.933333333333333,0.925490196078431,0.92156862745098,
    0.917647058823529,0.909803921568627,0.905882352941176,0.901960784313726,
    0.894117647058824,0.890196078431372,0.886274509803922,0.87843137254902,
    0.874509803921569,0.870588235294118,0.862745098039216,0.858823529411765,
    0.854901960784314,0.847058823529412,0.843137254901961,0.83921568627451,
    0.831372549019608,0.827450980392157,0.823529411764706,0.815686274509804,
    0.811764705882353,0.807843137254902,0.8,0.796078431372549,
    0.792156862745098,0.784313725490196,0.780392156862745,0.776470588235294,
    0.768627450980392,0.764705882352941,0.76078431372549,0.752941176470588,
    0.749019607843137,0.745098039215686,0.737254901960784,0.733333333333333,
    0.729411764705882,0.72156862745098,0.717647058823529,0.713725490196078,
    0.705882352941177,0.701960784313725,0.698039215686274,0.690196078431373,
    0.686274509803922,0.682352941176471,0.674509803921569,0.670588235294118,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.662745098039216,0.658823529411765,0.654901960784314,0.647058823529412,
    0.643137254901961,0.63921568627451,0.631372549019608,0.627450980392157,
    0.623529411764706,0.615686274509804,0.611764705882353,0.607843137254902,
    0.6,0.596078431372549,0.592156862745098,0.584313725490196,
    0.580392156862745,0.576470588235294,0.568627450980392,0.564705882352941,
    0.56078431372549,0.552941176470588,0.549019607843137,0.545098039215686,
    0.537254901960784,0.533333333333333,0.529411764705882,0.52156862745098,
    0.517647058823529,0.513725490196078,0.505882352941176,0.501960784313725,
    0.498039215686275,0.490196078431373,0.486274509803922,0.482352941176471,
    0.474509803921569,0.470588235294118,0.466666666666667,0.458823529411765,
    0.454901960784314,0.450980392156863,0.443137254901961,0.43921568627451,
    0.435294117647059,0.427450980392157,0.423529411764706,0.419607843137255,
    0.411764705882353,0.407843137254902,0.403921568627451,0.396078431372549,
    0.392156862745098,0.388235294117647,0.380392156862745,0.376470588235294,
    0.372549019607843,0.364705882352941,0.36078431372549,0.356862745098039,
    0.349019607843137,0.345098039215686,0.341176470588235,0.333333333333333,
    0.329411764705882,0.325490196078431,0.317647058823529,0.313725490196078,
    0.309803921568627,0.301960784313725,0.298039215686275,0.294117647058824,
    0.286274509803922,0.282352941176471,0.27843137254902,0.270588235294118,
    0.266666666666667,0.262745098039216,0.254901960784314,0.250980392156863,
    0.247058823529412,0.23921568627451,0.235294117647059,0.231372549019608,
    0.223529411764706,0.219607843137255,0.215686274509804,0.207843137254902,
    0.203921568627451,0.2,0.192156862745098,0.188235294117647,
    0.184313725490196,0.176470588235294,0.172549019607843,0.168627450980392,
    0.16078431372549,0.156862745098039,0.152941176470588,0.145098039215686,
    0.141176470588235,0.137254901960784,0.129411764705882,0.125490196078431,
    0.12156862745098,0.113725490196078,0.109803921568627,0.105882352941176,
    0.0980392156862745,0.0941176470588235,0.0901960784313725,0.0823529411764706,
    0.0784313725490196,0.0745098039215686,0.0666666666666667,0.0627450980392157,
    0.0588235294117647,0.0509803921568627,0.0470588235294118,0.0431372549019608,
    0.0352941176470588,0.0313725490196078,0.0274509803921569,0.0196078431372549,
    0.0156862745098039,0.0117647058823529,0.00392156862745098,0
  };

  const Rcpp::NumericVector ygobb_blue = {
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.658823529411765,0.654901960784314,0.650980392156863,
    0.643137254901961,0.63921568627451,0.635294117647059,0.627450980392157,
    0.623529411764706,0.619607843137255,0.611764705882353,0.607843137254902,
    0.603921568627451,0.596078431372549,0.592156862745098,0.588235294117647,
    0.580392156862745,0.576470588235294,0.572549019607843,0.564705882352941,
    0.56078431372549,0.556862745098039,0.549019607843137,0.545098039215686,
    0.541176470588235,0.533333333333333,0.529411764705882,0.525490196078431,
    0.517647058823529,0.513725490196078,0.509803921568627,0.501960784313725,
    0.498039215686275,0.494117647058824,0.486274509803922,0.482352941176471,
    0.47843137254902,0.470588235294118,0.466666666666667,0.462745098039216,
    0.454901960784314,0.450980392156863,0.447058823529412,0.43921568627451,
    0.435294117647059,0.431372549019608,0.423529411764706,0.419607843137255,
    0.415686274509804,0.407843137254902,0.403921568627451,0.4,
    0.392156862745098,0.388235294117647,0.384313725490196,0.376470588235294,
    0.372549019607843,0.368627450980392,0.36078431372549,0.356862745098039,
    0.352941176470588,0.345098039215686,0.341176470588235,0.337254901960784,
    0.337254901960784,0.341176470588235,0.345098039215686,0.352941176470588,
    0.356862745098039,0.36078431372549,0.368627450980392,0.372549019607843,
    0.376470588235294,0.384313725490196,0.388235294117647,0.392156862745098,
    0.4,0.403921568627451,0.407843137254902,0.415686274509804,
    0.419607843137255,0.423529411764706,0.431372549019608,0.435294117647059,
    0.43921568627451,0.447058823529412,0.450980392156863,0.454901960784314,
    0.462745098039216,0.466666666666667,0.470588235294118,0.47843137254902,
    0.482352941176471,0.486274509803922,0.494117647058824,0.498039215686275,
    0.501960784313725,0.509803921568627,0.513725490196078,0.517647058823529,
    0.525490196078431,0.529411764705882,0.533333333333333,0.541176470588235,
    0.545098039215686,0.549019607843137,0.556862745098039,0.56078431372549,
    0.564705882352941,0.572549019607843,0.576470588235294,0.580392156862745,
    0.588235294117647,0.592156862745098,0.596078431372549,0.603921568627451,
    0.607843137254902,0.611764705882353,0.619607843137255,0.623529411764706,
    0.627450980392157,0.635294117647059,0.63921568627451,0.643137254901961,
    0.650980392156863,0.654901960784314,0.658823529411765,0.666666666666667,
    0.658823529411765,0.647058823529412,0.63921568627451,0.627450980392157,
    0.615686274509804,0.607843137254902,0.596078431372549,0.584313725490196,
    0.576470588235294,0.564705882352941,0.552941176470588,0.545098039215686,
    0.533333333333333,0.52156862745098,0.513725490196078,0.501960784313725,
    0.490196078431373,0.482352941176471,0.470588235294118,0.458823529411765,
    0.450980392156863,0.43921568627451,0.427450980392157,0.419607843137255,
    0.407843137254902,0.396078431372549,0.388235294117647,0.376470588235294,
    0.364705882352941,0.356862745098039,0.345098039215686,0.333333333333333,
    0.325490196078431,0.313725490196078,0.301960784313725,0.294117647058824,
    0.282352941176471,0.270588235294118,0.262745098039216,0.250980392156863,
    0.23921568627451,0.231372549019608,0.219607843137255,0.207843137254902,
    0.2,0.188235294117647,0.176470588235294,0.168627450980392,
    0.156862745098039,0.145098039215686,0.137254901960784,0.125490196078431,
    0.113725490196078,0.105882352941176,0.0941176470588235,0.0823529411764706,
    0.0745098039215686,0.0627450980392157,0.0509803921568627,0.0431372549019608,
    0.0313725490196078,0.0196078431372549,0.0117647058823529,0
  };

const Rcpp::List ygobb = Rcpp::List::create(
  _["r"] = ygobb_red,
  _["g"] = ygobb_green,
  _["b"] = ygobb_blue
);
} // namespace palette
} // namepsace colourvalues

#endif

==> colourvalues_0.3.9.tar.gz: colourvalues/inst/include/colourvalues/palettes/ygobb.hpp <==
#ifndef R_COLOURVALUES_YGOBB_H
#define R_COLOURVALUES_YGOBB_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector ygobb_red = {
    1,0.996078431372549,0.988235294117647,0.984313725490196,
    0.980392156862745,0.972549019607843,0.968627450980392,0.964705882352941,
    0.956862745098039,0.952941176470588,0.949019607843137,0.941176470588235,
    0.937254901960784,0.933333333333333,0.925490196078431,0.92156862745098,
    0.917647058823529,0.909803921568627,0.905882352941176,0.901960784313726,
    0.894117647058824,0.890196078431372,0.886274509803922,0.87843137254902,
    0.874509803921569,0.870588235294118,0.862745098039216,0.858823529411765,
    0.854901960784314,0.847058823529412,0.843137254901961,0.83921568627451,
    0.831372549019608,0.827450980392157,0.823529411764706,0.815686274509804,
    0.811764705882353,0.807843137254902,0.8,0.796078431372549,
    0.792156862745098,0.784313725490196,0.780392156862745,0.776470588235294,
    0.768627450980392,0.764705882352941,0.76078431372549,0.752941176470588,
    0.749019607843137,0.745098039215686,0.737254901960784,0.733333333333333,
    0.729411764705882,0.72156862745098,0.717647058823529,0.713725490196078,
    0.705882352941177,0.701960784313725,0.698039215686274,0.690196078431373,
    0.686274509803922,0.682352941176471,0.674509803921569,0.670588235294118,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.662745098039216,0.658823529411765,0.654901960784314,0.647058823529412,
    0.643137254901961,0.63921568627451,0.631372549019608,0.627450980392157,
    0.623529411764706,0.615686274509804,0.611764705882353,0.607843137254902,
    0.6,0.596078431372549,0.592156862745098,0.584313725490196,
    0.580392156862745,0.576470588235294,0.568627450980392,0.564705882352941,
    0.56078431372549,0.552941176470588,0.549019607843137,0.545098039215686,
    0.537254901960784,0.533333333333333,0.529411764705882,0.52156862745098,
    0.517647058823529,0.513725490196078,0.505882352941176,0.501960784313725,
    0.498039215686275,0.490196078431373,0.486274509803922,0.482352941176471,
    0.474509803921569,0.470588235294118,0.466666666666667,0.458823529411765,
    0.454901960784314,0.450980392156863,0.443137254901961,0.43921568627451,
    0.435294117647059,0.427450980392157,0.423529411764706,0.419607843137255,
    0.411764705882353,0.407843137254902,0.403921568627451,0.396078431372549,
    0.392156862745098,0.388235294117647,0.380392156862745,0.376470588235294,
    0.372549019607843,0.364705882352941,0.36078431372549,0.356862745098039,
    0.349019607843137,0.345098039215686,0.341176470588235,0.333333333333333,
    0.329411764705882,0.325490196078431,0.317647058823529,0.313725490196078,
    0.309803921568627,0.301960784313725,0.298039215686275,0.294117647058824,
    0.286274509803922,0.282352941176471,0.27843137254902,0.270588235294118,
    0.266666666666667,0.262745098039216,0.254901960784314,0.250980392156863,
    0.247058823529412,0.23921568627451,0.235294117647059,0.231372549019608,
    0.223529411764706,0.219607843137255,0.215686274509804,0.207843137254902,
    0.203921568627451,0.2,0.192156862745098,0.188235294117647,
    0.184313725490196,0.176470588235294,0.172549019607843,0.168627450980392,
    0.16078431372549,0.156862745098039,0.152941176470588,0.145098039215686,
    0.141176470588235,0.137254901960784,0.129411764705882,0.125490196078431,
    0.12156862745098,0.113725490196078,0.109803921568627,0.105882352941176,
    0.0980392156862745,0.0941176470588235,0.0901960784313725,0.0823529411764706,
    0.0784313725490196,0.0745098039215686,0.0666666666666667,0.0627450980392157,
    0.0588235294117647,0.0509803921568627,0.0470588235294118,0.0431372549019608,
    0.0352941176470588,0.0313725490196078,0.0274509803921569,0.0196078431372549,
    0.0156862745098039,0.0117647058823529,0.00392156862745098,0
  };

  const Rcpp::NumericVector ygobb_green = {
    1,0.996078431372549,0.988235294117647,0.984313725490196,
    0.980392156862745,0.972549019607843,0.968627450980392,0.964705882352941,
    0.956862745098039,0.952941176470588,0.949019607843137,0.941176470588235,
    0.937254901960784,0.933333333333333,0.925490196078431,0.92156862745098,
    0.917647058823529,0.909803921568627,0.905882352941176,0.901960784313726,
    0.894117647058824,0.890196078431372,0.886274509803922,0.87843137254902,
    0.874509803921569,0.870588235294118,0.862745098039216,0.858823529411765,
    0.854901960784314,0.847058823529412,0.843137254901961,0.83921568627451,
    0.831372549019608,0.827450980392157,0.823529411764706,0.815686274509804,
    0.811764705882353,0.807843137254902,0.8,0.796078431372549,
    0.792156862745098,0.784313725490196,0.780392156862745,0.776470588235294,
    0.768627450980392,0.764705882352941,0.76078431372549,0.752941176470588,
    0.749019607843137,0.745098039215686,0.737254901960784,0.733333333333333,
    0.729411764705882,0.72156862745098,0.717647058823529,0.713725490196078,
    0.705882352941177,0.701960784313725,0.698039215686274,0.690196078431373,
    0.686274509803922,0.682352941176471,0.674509803921569,0.670588235294118,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.662745098039216,0.658823529411765,0.654901960784314,0.647058823529412,
    0.643137254901961,0.63921568627451,0.631372549019608,0.627450980392157,
    0.623529411764706,0.615686274509804,0.611764705882353,0.607843137254902,
    0.6,0.596078431372549,0.592156862745098,0.584313725490196,
    0.580392156862745,0.576470588235294,0.568627450980392,0.564705882352941,
    0.56078431372549,0.552941176470588,0.549019607843137,0.545098039215686,
    0.537254901960784,0.533333333333333,0.529411764705882,0.52156862745098,
    0.517647058823529,0.513725490196078,0.505882352941176,0.501960784313725,
    0.498039215686275,0.490196078431373,0.486274509803922,0.482352941176471,
    0.474509803921569,0.470588235294118,0.466666666666667,0.458823529411765,
    0.454901960784314,0.450980392156863,0.443137254901961,0.43921568627451,
    0.435294117647059,0.427450980392157,0.423529411764706,0.419607843137255,
    0.411764705882353,0.407843137254902,0.403921568627451,0.396078431372549,
    0.392156862745098,0.388235294117647,0.380392156862745,0.376470588235294,
    0.372549019607843,0.364705882352941,0.36078431372549,0.356862745098039,
    0.349019607843137,0.345098039215686,0.341176470588235,0.333333333333333,
    0.329411764705882,0.325490196078431,0.317647058823529,0.313725490196078,
    0.309803921568627,0.301960784313725,0.298039215686275,0.294117647058824,
    0.286274509803922,0.282352941176471,0.27843137254902,0.270588235294118,
    0.266666666666667,0.262745098039216,0.254901960784314,0.250980392156863,
    0.247058823529412,0.23921568627451,0.235294117647059,0.231372549019608,
    0.223529411764706,0.219607843137255,0.215686274509804,0.207843137254902,
    0.203921568627451,0.2,0.192156862745098,0.188235294117647,
    0.184313725490196,0.176470588235294,0.172549019607843,0.168627450980392,
    0.16078431372549,0.156862745098039,0.152941176470588,0.145098039215686,
    0.141176470588235,0.137254901960784,0.129411764705882,0.125490196078431,
    0.12156862745098,0.113725490196078,0.109803921568627,0.105882352941176,
    0.0980392156862745,0.0941176470588235,0.0901960784313725,0.0823529411764706,
    0.0784313725490196,0.0745098039215686,0.0666666666666667,0.0627450980392157,
    0.0588235294117647,0.0509803921568627,0.0470588235294118,0.0431372549019608,
    0.0352941176470588,0.0313725490196078,0.0274509803921569,0.0196078431372549,
    0.0156862745098039,0.0117647058823529,0.00392156862745098,0
  };

  const Rcpp::NumericVector ygobb_blue = {
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.666666666666667,0.666666666666667,0.666666666666667,
    0.666666666666667,0.658823529411765,0.654901960784314,0.650980392156863,
    0.643137254901961,0.63921568627451,0.635294117647059,0.627450980392157,
    0.623529411764706,0.619607843137255,0.611764705882353,0.607843137254902,
    0.603921568627451,0.596078431372549,0.592156862745098,0.588235294117647,
    0.580392156862745,0.576470588235294,0.572549019607843,0.564705882352941,
    0.56078431372549,0.556862745098039,0.549019607843137,0.545098039215686,
    0.541176470588235,0.533333333333333,0.529411764705882,0.525490196078431,
    0.517647058823529,0.513725490196078,0.509803921568627,0.501960784313725,
    0.498039215686275,0.494117647058824,0.486274509803922,0.482352941176471,
    0.47843137254902,0.470588235294118,0.466666666666667,0.462745098039216,
    0.454901960784314,0.450980392156863,0.447058823529412,0.43921568627451,
    0.435294117647059,0.431372549019608,0.423529411764706,0.419607843137255,
    0.415686274509804,0.407843137254902,0.403921568627451,0.4,
    0.392156862745098,0.388235294117647,0.384313725490196,0.376470588235294,
    0.372549019607843,0.368627450980392,0.36078431372549,0.356862745098039,
    0.352941176470588,0.345098039215686,0.341176470588235,0.337254901960784,
    0.337254901960784,0.341176470588235,0.345098039215686,0.352941176470588,
    0.356862745098039,0.36078431372549,0.368627450980392,0.372549019607843,
    0.376470588235294,0.384313725490196,0.388235294117647,0.392156862745098,
    0.4,0.403921568627451,0.407843137254902,0.415686274509804,
    0.419607843137255,0.423529411764706,0.431372549019608,0.435294117647059,
    0.43921568627451,0.447058823529412,0.450980392156863,0.454901960784314,
    0.462745098039216,0.466666666666667,0.470588235294118,0.47843137254902,
    0.482352941176471,0.486274509803922,0.494117647058824,0.498039215686275,
    0.501960784313725,0.509803921568627,0.513725490196078,0.517647058823529,
    0.525490196078431,0.529411764705882,0.533333333333333,0.541176470588235,
    0.545098039215686,0.549019607843137,0.556862745098039,0.56078431372549,
    0.564705882352941,0.572549019607843,0.576470588235294,0.580392156862745,
    0.588235294117647,0.592156862745098,0.596078431372549,0.603921568627451,
    0.607843137254902,0.611764705882353,0.619607843137255,0.623529411764706,
    0.627450980392157,0.635294117647059,0.63921568627451,0.643137254901961,
    0.650980392156863,0.654901960784314,0.658823529411765,0.666666666666667,
    0.658823529411765,0.647058823529412,0.63921568627451,0.627450980392157,
    0.615686274509804,0.607843137254902,0.596078431372549,0.584313725490196,
    0.576470588235294,0.564705882352941,0.552941176470588,0.545098039215686,
    0.533333333333333,0.52156862745098,0.513725490196078,0.501960784313725,
    0.490196078431373,0.482352941176471,0.470588235294118,0.458823529411765,
    0.450980392156863,0.43921568627451,0.427450980392157,0.419607843137255,
    0.407843137254902,0.396078431372549,0.388235294117647,0.376470588235294,
    0.364705882352941,0.356862745098039,0.345098039215686,0.333333333333333,
    0.325490196078431,0.313725490196078,0.301960784313725,0.294117647058824,
    0.282352941176471,0.270588235294118,0.262745098039216,0.250980392156863,
    0.23921568627451,0.231372549019608,0.219607843137255,0.207843137254902,
    0.2,0.188235294117647,0.176470588235294,0.168627450980392,
    0.156862745098039,0.145098039215686,0.137254901960784,0.125490196078431,
    0.113725490196078,0.105882352941176,0.0941176470588235,0.0823529411764706,
    0.0745098039215686,0.0627450980392157,0.0509803921568627,0.0431372549019608,
    0.0313725490196078,0.0196078431372549,0.0117647058823529,0
  };

  // const Rcpp::List ygobb = Rcpp::List::create(
  //   _["r"] = ygobb_red,
  //   _["g"] = ygobb_green,
  //   _["b"] = ygobb_blue
  // );
} // namespace palette
} // namepsace colourvalues

#endif
